/**
 * This class will spawn a dialog asking to exit the game in case the user was an assigned player who has been defeated.
 */
class QuitConfirmationDefeat extends QuitConfirmation
{
	constructor()
	{
		super();

		if (Engine.IsAtlasRunning())
			return;

		this.confirmHandler = undefined;
		registerPlayersFinishedHandler(this.onPlayersFinished.bind(this));
	}

	onPlayersFinished(players, won)
	{
		if (players.indexOf(Engine.GetPlayerID()) == -1)
			return;

		// Defer simulation result until
		// 1. the loading screen finished for all networked clients (g_IsNetworkedActive)
		// 2. all messages modifying g_Players victory state were processed (next turn)
		this.confirmHandler = this.confirmExit.bind(this, won);
		registerSimulationUpdateHandler(this.confirmHandler);
	}

	confirmExit(won)
	{
		if (g_IsNetworked && !g_IsNetworkedActive)
			return;

		unregisterSimulationUpdateHandler(this.confirmHandler);

		// Don't invite the host to exit if other humans are still playing.
		let askExit = !Engine.HasNetServer() || g_Players.every((player, i) =>
			i == 0 ||
			player.state != "active" ||
			g_InitAttributes.settings.PlayerData[i].AI != "");

		this.Title = won ? this.TitleVictory : this.TitleDefeated;
		this.MsgTitle = this.Question;

		const playerID = Engine.GetPlayerID();

		this.VictoryBackground = g_CivData[g_Players[playerID].civ].EndGameVictoryBackground || this.VictoryBackgroundFallback;
		this.DefeatedBackground = g_CivData[g_Players[playerID].civ].EndGameDefeatedBackground || this.DefeatedBackgroundFallback;
		this.Background = won ? this.VictoryBackground : this.DefeatedBackground;

		this.VictoryImage = g_CivData[g_Players[playerID].civ].EndGameVictoryImage || this.VictoryImageFallback;
		this.DefeatedImage = g_CivData[g_Players[playerID].civ].EndGameDefeatedImage || this.DefeatedImageFallback;
		this.Image = won ? this.VictoryImage : this.DefeatedImage;

		this.VictoryOverlay = g_CivData[g_Players[playerID].civ].EndGameVictoryOverlay || this.VictoryOverlayFallback;
		this.DefeatedOverlay = g_CivData[g_Players[playerID].civ].EndGameDefeatedOverlay || this.DefeatedOverlayFallback;
		this.Overlay = won ? this.VictoryOverlay : this.DefeatedOverlay;

		this.TitleStyle = won ? this.VictoryTitleStyle : this.DefeatedTitleStyle;

		this.Buttons = askExit ? super.Buttons : undefined;

		this.endGameDisplay();
	}
}

QuitConfirmationDefeat.prototype.TitleVictory = translate("VICTORIOUS!");
QuitConfirmationDefeat.prototype.TitleDefeated = translate("DEFEATED!");

QuitConfirmationDefeat.prototype.Question = translate("Do you want to quit?");

QuitConfirmationDefeat.prototype.VictoryTitleStyle = "EndgameTitleVictory";
QuitConfirmationDefeat.prototype.DefeatedTitleStyle = "EndgameTitleDefeat";

QuitConfirmationDefeat.prototype.VictoryBackgroundFallback = "session/icons/bkg/background_victory_glow.png";
QuitConfirmationDefeat.prototype.DefeatedBackgroundFallback = "session/icons/bkg/background_defeat_shadow.png";

QuitConfirmationDefeat.prototype.VictoryImageFallback = "session/icons/bkg/background_circle_mace.png";
QuitConfirmationDefeat.prototype.DefeatedImageFallback = "session/icons/bkg/background_circle_mace.png";

QuitConfirmationDefeat.prototype.VictoryOverlayFallback = "session/icons/bkg/background_victory_overlay.png";
QuitConfirmationDefeat.prototype.DefeatedOverlayFallback = "session/icons/bkg/background_defeat_overlay.png";
